==> logicFS_1.22.0.zip: logicFS/doc/logicFS.R <==
###################################################
### chunk number 1: 
###################################################
#line 57 "logicFS.Rnw"
library(logicFS)


###################################################
### chunk number 2: 
###################################################
#line 63 "logicFS.Rnw"
data(data.logicfs)


###################################################
### chunk number 3: 
###################################################
#line 95 "logicFS.Rnw"
bin.snps<-make.snp.dummy(data.logicfs)


###################################################
### chunk number 4: 
###################################################
#line 108 "logicFS.Rnw"
my.anneal<-logreg.anneal.control(start=2, end=-2, iter=10000)


###################################################
### chunk number 5: 
###################################################
#line 115 "logicFS.Rnw"
log.out<-logicFS(bin.snps, cl.logicfs, B=20, nleaves=10, rand=123, anneal.control=my.anneal)


###################################################
### chunk number 6: 
###################################################
#line 125 "logicFS.Rnw"
log.out


###################################################
### chunk number 7:  eval=FALSE
###################################################
## #line 137 "logicFS.Rnw"
## plot(log.out)


###################################################
### chunk number 8: 
###################################################
#line 168 "logicFS.Rnw"
bag.out<-logic.bagging(bin.snps, cl.logicfs, B=20, nleaves=10, rand=123, anneal.control=my.anneal)
bag.out


###################################################
### chunk number 9: 
###################################################
#line 177 "logicFS.Rnw"
bag.out$vim


###################################################
### chunk number 10: 
###################################################
#line 186 "logicFS.Rnw"
cl.preds<-predict(bag.out,bin.snps)


###################################################
### chunk number 11: 
###################################################
#line 193 "logicFS.Rnw"
mean(cl.preds!=cl.logicfs)

==> logicFS_1.28.1.zip: logicFS/doc/logicFS.R <==
### R code from vignette source 'logicFS.Rnw'

###################################################
### code chunk number 1: logicFS.Rnw:56-57
###################################################
library(logicFS)


###################################################
### code chunk number 2: logicFS.Rnw:62-63
###################################################
data(data.logicfs)


###################################################
### code chunk number 3: logicFS.Rnw:94-95
###################################################
bin.snps<-make.snp.dummy(data.logicfs)


###################################################
### code chunk number 4: logicFS.Rnw:107-108
###################################################
my.anneal<-logreg.anneal.control(start=2, end=-2, iter=10000)


###################################################
### code chunk number 5: logicFS.Rnw:114-115
###################################################
log.out<-logicFS(bin.snps, cl.logicfs, B=20, nleaves=10, rand=123, anneal.control=my.anneal)


###################################################
### code chunk number 6: logicFS.Rnw:124-125
###################################################
log.out


###################################################
### code chunk number 7: logicFS.Rnw:136-137 (eval = FALSE)
###################################################
## plot(log.out)


###################################################
### code chunk number 8: logicFS.Rnw:167-169
###################################################
bag.out<-logic.bagging(bin.snps, cl.logicfs, B=20, nleaves=10, rand=123, anneal.control=my.anneal)
bag.out


###################################################
### code chunk number 9: logicFS.Rnw:176-177
###################################################
bag.out$vim


###################################################
### code chunk number 10: logicFS.Rnw:185-186
###################################################
cl.preds<-predict(bag.out,bin.snps)


###################################################
### code chunk number 11: logicFS.Rnw:192-193
###################################################
mean(cl.preds!=cl.logicfs)
